@@ -46,7 +46,7 @@ static const int specialMimeTypeCount = 10;
 
 struct MimeTypes
 {
-    QVector<QMimeType> all;
+    QList<QMimeType> all;
     QStringList image;
     QStringList video;
     QStringList audio;
@@ -171,7 +171,7 @@ KfindTabWidget::KfindTabWidget(QWidget *parent)
     andL->setObjectName(QStringLiteral("and"));
     betweenType = new KComboBox(pages[1]);
     betweenType->setObjectName(QStringLiteral("comboBetweenType"));
-    betweenType->addItems(QVector<QString>(5).toList()); // texts set in updateDateLabels
+    betweenType->addItems(QList<QString>(5).toList()); // texts set in updateDateLabels
     betweenType->setCurrentIndex(1);
     updateDateLabels(1, 1);
 
@@ -430,7 +430,7 @@ KfindTabWidget::~KfindTabWidget()
 
 void KfindTabWidget::setURL(const QUrl &url)
 {
-    KConfigGroup conf(KSharedConfig::openConfig(), "History");
+    KConfigGroup conf(KSharedConfig::openConfig(), QStringLiteral("History"));
     m_url = url;
     QStringList sl = conf.readPathEntry("Directories", QStringList());
     dirBox->clear(); // make sure there is no old Stuff in there
@@ -633,17 +633,8 @@ void KfindTabWidget::setQuery(KQuery *query)
 // Or is there an arch where this can happen?
 #if 0
     if (size < 0) { // overflow
-#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
         if (KMessageBox::warningTwoActions(this, i18n("Size is too big. Set maximum size value?"), i18n("Error"), i18n("Set"), i18n("Do Not Set"))
-#else
-        if (KMessageBox::warningYesNo(this, i18n("Size is too big. Set maximum size value?"), i18n("Error"), i18n("Set"), i18n("Do Not Set"))
-
-#endif
-#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
             == KMessageBox::ButtonCode::PrimaryAction) {
-#else
-            == KMessageBox::Yes) {
-#endif
             sizeEdit->setValue(INT_MAX);
             sizeUnitBox->setCurrentIndex(0);
             size = INT_MAX;
